Method: Nmap::XML#down_host
- Defined in:
- lib/nmap/xml.rb
#down_host ⇒ Host
Returns the first host found to be down during the scan.
376 377 378 |
# File 'lib/nmap/xml.rb', line 376 def down_host each_down_host.first end |
Returns the first host found to be down during the scan.
376 377 378 |
# File 'lib/nmap/xml.rb', line 376 def down_host each_down_host.first end |