Method: Nmap::XML#down_hosts
- Defined in:
- lib/nmap/xml.rb
#down_hosts ⇒ Array<Host>
Parses the hosts found to be down during the scan.
365 366 367 |
# File 'lib/nmap/xml.rb', line 365 def down_hosts each_down_host.to_a end |
Parses the hosts found to be down during the scan.
365 366 367 |
# File 'lib/nmap/xml.rb', line 365 def down_hosts each_down_host.to_a end |