Method: Nmap::XML#up_hosts
- Defined in:
- lib/nmap/xml.rb
#up_hosts ⇒ Array<Host>
Parses the hosts found to be up during the scan.
409 410 411 |
# File 'lib/nmap/xml.rb', line 409 def up_hosts each_up_host.to_a end |
Parses the hosts found to be up during the scan.
409 410 411 |
# File 'lib/nmap/xml.rb', line 409 def up_hosts each_up_host.to_a end |